summaryrefslogtreecommitdiffstats
path: root/plugins/scheduler/schedulerprefpagewidget.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 20:34:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 20:34:15 +0000
commit1c1403293485f35fd53db45aaa77a01cdd9627e7 (patch)
tree38559cd68cd4f63023fb5f6375def9db3b8b491e /plugins/scheduler/schedulerprefpagewidget.cpp
parent894f94545727610df22c4f73911d62d58266f695 (diff)
downloadktorrent-1c1403293485f35fd53db45aaa77a01cdd9627e7.tar.gz
ktorrent-1c1403293485f35fd53db45aaa77a01cdd9627e7.zip
TQt4 port ktorrent
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktorrent@1238733 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'plugins/scheduler/schedulerprefpagewidget.cpp')
-rw-r--r--plugins/scheduler/schedulerprefpagewidget.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/plugins/scheduler/schedulerprefpagewidget.cpp b/plugins/scheduler/schedulerprefpagewidget.cpp
index d6e73dd..ad12e73 100644
--- a/plugins/scheduler/schedulerprefpagewidget.cpp
+++ b/plugins/scheduler/schedulerprefpagewidget.cpp
@@ -22,16 +22,16 @@
#include "bwscheduler.h"
#include "schedulerpluginsettings.h"
-#include <qcheckbox.h>
-#include <qtimer.h>
-#include <qpushbutton.h>
-#include <qgroupbox.h>
+#include <tqcheckbox.h>
+#include <tqtimer.h>
+#include <tqpushbutton.h>
+#include <tqgroupbox.h>
namespace kt
{
- SchedulerPrefPageWidget::SchedulerPrefPageWidget(QWidget* parent, const char* name, WFlags fl)
- : SchedulerPage(parent,name,fl)
+ SchedulerPrefPageWidget::SchedulerPrefPageWidget(TQWidget* tqparent, const char* name, WFlags fl)
+ : SchedulerPage(tqparent,name,fl)
{
groupBWS->setEnabled(false);
bool useit = SchedulerPluginSettings::enableBWS();
@@ -59,9 +59,9 @@ namespace kt
SchedulerPluginSettings::writeConfig();
/* force trigger since the schedule has changed but after KTorrent::apply()
* Used QTimer with fixed interval - not very nice solution... */
if(useBS->isChecked())
- QTimer::singleShot(1000, this, SLOT(scheduler_trigger()));
+ TQTimer::singleShot(1000, this, TQT_SLOT(scheduler_trigger()));
BWScheduler::instance().setEnabled(use_bws);
}
@@ -59,9 +59,9 @@ namespace kt
SchedulerPluginSettings::writeConfig();
/* force trigger since the schedule has changed but after KTorrent::apply()
- * Used QTimer with fixed interval - not very nice solution... */
+ * Used TQTimer with fixed interval - not very nice solution... */
if(useBS->isChecked())